Series Expansions
=================

The series module implements series expansions as a
function and many related functions.

.. automodule:: diofant.series.limits
   :members:

.. automodule:: diofant.series.series
   :members:

.. automodule:: diofant.series.order
   :members:

.. automodule:: diofant.series.residues
   :members:
